# sopel-genius-answer
A sopel plugin (irc-bot) to answer with a quote from rapgenius.com

### Install genius-answer plugin

```bash
$ pip install sopel_modules.genius-answer
```

### Configure genius-answer

To create the genius token, see https://github.com/johnwmillr/lyricsgenius#setup  
In ``default.cfg`` config file, add a ``[genius]`` section with ``api_key`` as

```ini
[genius]
api_key = xxxxxxxxxxxxxxxxx
```
